{ pkgs, ... }:

with pkgs.haskell.lib;

final: prev: {

  Agda = null;

  HsOpenSSL = appendConfigureFlags prev.HsOpenSSL [
    "--ghc-option=-optc=-Wno-error=incompatible-pointer-types"
  ];

  digest = addPkgconfigDepend prev.digest pkgs.zlib;

  chell-quickcheck = null;

  chell = null;

  extensible-effects = null;

  persistent-qq = null;

  protolude = null;

  sdl2 = addSetupDepends
    (overrideCabal (prev.sdl2.overrideAttrs (old : old // { patchFlags = ["--binary"]; }))
      { __onlyPropagateKnownPkgConfigModules = true; }
    )
    [ pkgs.pkg-config pkgs.SDL2 ];

  sdl2-gfx = addSetupDepends
    (overrideCabal prev.sdl2-gfx
      { __onlyPropagateKnownPkgConfigModules = true; }
    )
    [ pkgs.pkg-config pkgs.SDL2 ];

  sdl2-image =
    addSetupDepends
      (overrideCabal prev.sdl2-image
        { __onlyPropagateKnownPkgConfigModules = true; }
      )
      [ pkgs.pkg-config pkgs.SDL2 pkgs.libtiff pkgs.libwebp pkgs.lerc ];

  sdl2-mixer =
    addSetupDepends
      (overrideCabal prev.sdl2-mixer
        { __onlyPropagateKnownPkgConfigModules = true; }
      )
      (if pkgs.stdenv.isLinux then
        [ pkgs.pkg-config pkgs.SDL2 pkgs.libsysprof-capture pkgs.libsndfile pkgs.libpulseaudio pkgs.alsa-lib pkgs.jack2 pkgs.glib pkgs.pcre2 ]
      else
        [ pkgs.pkg-config pkgs.SDL2 pkgs.libsndfile pkgs.glib pkgs.pcre2 pkgs.jack2 pkgs.libsysprof-capture ]);

  sdl2-ttf =
    addSetupDepends
      (overrideCabal prev.sdl2-ttf
        { __onlyPropagateKnownPkgConfigModules = true; }
      )
      [ pkgs.pkg-config pkgs.SDL2 pkgs.SDL2_ttf pkgs.harfbuzz pkgs.freetype pkgs.glib pkgs.pcre2 pkgs.libsysprof-capture ];

  stringsearch = prev.stringsearch.overrideAttrs (old : old // { patchFlags = ["--binary"]; });

  postgresql-libpq-configure = addPkgconfigDepend prev.postgresql-libpq-configure pkgs.postgresql;

  vulkan = prev.callPackage ./pkgs/vulkan.nix { vulkan = pkgs.vulkan-loader; };

}

